@@ -14,13 +14,13 @@
 # limitations under the License.
 ##
 
-labkey.getFolders <- function(baseUrl, folderPath, includeEffectivePermissions=TRUE, includeSubfolders=FALSE, depth=50)
+labkey.getFolders <- function(baseUrl=NULL, folderPath, includeEffectivePermissions=TRUE, includeSubfolders=FALSE, depth=50)
 {
-## Empty string/NULL checking
+baseUrl=labkey.getBaseUrl(baseUrl)    
 
-## Error if either baseUrl or folderPath
-if(exists("baseUrl")==FALSE || exists("folderPath")==FALSE)
-stop (paste("A value must be specified for both baseUrl and folderPath"))
+## Empty string/NULL checking
+if(exists("baseUrl")==FALSE || is.null(baseUrl) || exists("folderPath")==FALSE)
+    stop (paste("A value must be specified for both baseUrl and folderPath"))
 
 ## URL encoding of folder path  (if not already encoded)
 if(folderPath==URLdecode(folderPath)) {folderPath <- URLencode(folderPath)}
@@ -57,6 +57,4 @@ colnames(allpathsDF) <- c("name", "folderPath", "effectivePermissions")
 
 return(allpathsDF)
 
-}
-
-
+}
\ No newline at end of file
